subroutine Newton1ss(fun,gues1,gues2)

! This subroutine computes the steady state interest rate and labor supply with
! the classical newton method; inputs are the guesses for r and N and the subroutine
! that delivers the residual from markets clearing in the asset market and the 
! labor market

use params

implicit none

integer :: i, maxit=150
double precision, parameter :: weight=.4, weight_p=.4
double precision :: gues1,gues2,ngues1,ngues2,fval1,fval2
double precision, parameter :: tol=1e-3
double precision :: d1, d2, d3, d4, d5

double precision :: dummy, transfers, temp
double precision,dimension(ne,nh,J) :: Trn, Gvhc, Fhc, payers
double precision :: Trss1, taufss1, ghexpss1
double precision,dimension(ne,nh,J) :: pr_gss1
double precision :: d6
double precision :: buyers(ne,J)

    do i=1,maxit

        call fun(gues1,gues2,fval1,fval2)

	!new interest rate and labor in SS
	ngues1=theta*alpha*((N1ss*(1+nn)/Asss)**(1-alpha))-delta
	ngues2=N1ss

	! Compute accidental bequests
	Trn=0
	transfers=0

            do ec=1,ne
            do hc=1,nh
            do tc=1,J
                do gc=1,ng				
                do sc=1,ns
                Trn(ec,hc,tc)=Trn(ec,hc,tc)+sum(afunss(gc,ec,hc,sc,1:na,tc)*Phissadjusted(gc,ec,hc,sc,1:na,tc)) 
                end do
                end do
            transfers=transfers+(1-psi(ec,hc,tc))*Nuss(ec,hc,tc)*Trn(ec,hc,tc)
            end do
            end do
            end do

	!transfer from dead to each person is total transfers divided by total population
	Trss1=transfers/((1+nn)*sum(Nuss(1:ne,1:nh,1:J)))		

	!government expenditure on medicare, medicaid, and welfare
	Gvhc=0
	medicaidexpss=0
	!expense and count on foodstamps
	safetyss=0
	safetycntss=0
	
            do ec=1,ne
            do hc=1,nh
            do tc=1,J

                if ( hc .gt. sicklevel ) then
                sick=1
                else
                sick=0
                end if

            economy=economyss(tc)
            dummy=0

                if ( economy .eq. 'u' ) then

                    do gc=1,ng
                    do sc=1,ns
                    do ac=1,na
                    dummy=dummy+e_h(hc,tc)*Phissadjusted(gc,ec,hc,sc,ac,tc)
                    end do
                    end do
                    end do

                else if ( economy .eq. 'm' ) then

                    !Medicare expenditure
                    if ( tc .ge. jr ) then
                                
                        do gc=1,ng
                        do sc=1,ns
                        do ac=1,na
                        dummy=dummy+cov_mss*e_h(hc,tc)*Phissadjusted(gc,ec,hc,sc,ac,tc)
                        end do
                        end do
                        end do
                        
                    end if
			
                    !Medicaid expenditure and net rev from ACA subsidies and penalties
                    do gc=1,ng
                    do sc=1,ns
                    do ac=1,na
                    
                    dummy=dummy+medicaidexpfunss(gc,ec,hc,sc,ac,tc)*&
                    Phissadjusted(gc,ec,hc,sc,ac,tc)
								
                    medicaidexpss=medicaidexpss+medicaidexpfunss(gc,ec,hc,sc,ac,tc)*&
                    Phissadjusted(gc,ec,hc,sc,ac,tc)*Nuss(ec,hc,tc)
								
                    dummy=dummy+netfunss(gc,ec,hc,sc,ac,tc)*&
                    Phissadjusted(gc,ec,hc,sc,ac,tc)
                    
                    end do
                    end do
                    end do

                    do gc=1,ng
                    do sc=1,ns
                    do ac=1,na
                    safetycntss=safetycntss+(1-g_dfss(gc,ec,hc,sc,ac,tc))*Phissadjusted(gc,ec,hc,sc,ac,tc)*Nuss(ec,hc,tc)/sum(Nuss)
                    end do
                    end do
                    end do
		
                    !foodstamps expenditure
                    if ( tc .lt. jr ) then
                        do gc=1,ng
                        do sc=1,ns
                        do ac=1,na

                            if ( gc .eq. 2 .or. gc .eq. 3 ) then
                            dummy=dummy+(1-g_dfss(gc,ec,hc,sc,ac,tc))*&
                            (e_h(hc,tc)+cmin-(1+rss*(1-taukss))&
                            *(grida(ac)+Trss))*Phissadjusted(gc,ec,hc,sc,ac,tc)
                            safetyss=safetyss+(1-g_dfss(gc,ec,hc,sc,ac,tc))*&
                            (e_h(hc,tc)+cmin-(1+rss*(1-taukss))&
                            *(grida(ac)+Trss))*Phissadjusted(gc,ec,hc,sc,ac,tc)*nuss(ec,hc,tc)


                            else if ( gc .eq. 1 ) then
                            dummy=dummy+(1-g_dfss(gc,ec,hc,sc,ac,tc))*&
                            ((1-cov_p(hc))*e_h(hc,tc)+cmin-(1+rss*(1-taukss))&
                            *(grida(ac)+Trss))*Phissadjusted(gc,ec,hc,sc,ac,tc)

                            safetyss=safetyss+(1-g_dfss(gc,ec,hc,sc,ac,tc))*&
                            ((1-cov_p(hc))*e_h(hc,tc)+cmin-(1+rss*(1-taukss))&
                            *(grida(ac)+Trss))*Phissadjusted(gc,ec,hc,sc,ac,tc)*nuss(ec,hc,tc)

                            end if

                        end do
                        end do
                        end do

                    else if ( tc .ge. jr ) then
			
                        do gc=1,ng
                        do sc=1,ns
                        do ac=1,na
                                                                            
                            if ( gc .eq. 2 .or. gc .eq. 3 ) then
                            dummy=dummy+(1-g_dfss(gc,ec,hc,sc,ac,tc))*&
                            ((1-cov_mss)*e_h(hc,tc)+cmin-(1+rss*(1-taukss))&
                            *(grida(ac)+Trss)-SSss(ec))*Phissadjusted(gc,ec,hc,sc,ac,tc)
                            
                            safetyss=safetyss+(1-g_dfss(gc,ec,hc,sc,ac,tc))*&
                            ((1-cov_mss)*e_h(hc,tc)+cmin-(1+rss*(1-taukss))&
                            *(grida(ac)+Trss)-SSss(ec))*Phissadjusted(gc,ec,hc,sc,ac,tc)*nuss(ec,hc,tc)

                            else if ( gc .eq. 1 ) then
                            
                            dummy=dummy+(1-g_dfss(gc,ec,hc,sc,ac,tc))*&
                            ((1-cov_p(hc))*(1-cov_mss)*e_h(hc,tc)+cmin-(1+rss*(1-taukss))&
                            *(grida(ac)+Trss)-SSss(ec))*Phissadjusted(gc,ec,hc,sc,ac,tc)

                            safetyss=safetyss+(1-g_dfss(gc,ec,hc,sc,ac,tc))*&
                            ((1-cov_p(hc))*(1-cov_mss)*e_h(hc,tc)+cmin-(1+rss*(1-taukss))&
                            *(grida(ac)+Trss)-SSss(ec))*Phissadjusted(gc,ec,hc,sc,ac,tc)*nuss(ec,hc,tc)

                            end if
                        end do
                        end do
                        end do
                    end if
						
                end if
		
            Gvhc(ec,hc,tc)=Nuss(ec,hc,tc)*dummy
            
            end do
            end do
            end do

	ghexpss1=sum(Gvhc)
	
	!employer insurance tax
	Fhc=zero
	payers=zero

            do ec=1,ne
            do hc=1,nh

                if ( hc .gt. sicklevel ) then
                sick=1
                else
                sick=0
                end if

                do tc=1,jr-1
                            
                economy=economyss(tc)
                dummy=0
                temp=0
		
                    if ( economy .eq. 'm' ) then

                        do sc=1,ns
                        do ac=1,na
                        !no welfare/foodstamps
                            if ( g_dfss(3,ec,hc,sc,ac,tc) .eq. 1 ) then
                            dummy=dummy+cov_e(hc)*e_h(hc,tc)*Phissadjusted(3,ec,hc,sc,ac,tc)

                                if ( lfunss(3,ec,hc,sc,ac,tc) .gt. zero ) then
                                temp=temp+Phissadjusted(3,ec,hc,sc,ac,tc)
                                end if

                            end if
                        end do
                        end do

                    end if

                Fhc(ec,hc,tc)=Nuss(ec,hc,tc)*dummy
                payers(ec,hc,tc)=Nuss(ec,hc,tc)*temp
                
                end do
            end do
            end do

            if ( sum(Fhc) .eq. zero ) then
            taufss1=zero
            else
            taufss1=sum(Fhc)/sum(payers)
            end if

	d1=abs(fval1)/Asss
	d2=abs(fval2)/Nss
	d3=abs(Trss1-Trss)
	d4=abs(ghexpss1-ghexpss)/ghexpss
	d4=d4/10
	d5=abs(taufss1-taufss)
	
            if ( conditionss .eq. 0 ) then
    	    buyers=0
            pr_gss1=zero
    
                do ec=1,ne
                    do tc=1,J-1
                    dummy=zero       
                    
                        do hc=1,nh
                        do gc=1,ng
                        do sc=1,ns
                        do ac=1,na
                            if ( tc .lt. jr-1 ) then
                            pr_gss1(ec,1,tc)=pr_gss1(ec,1,tc)+g_dgss(gc,ec,hc,sc,ac,tc)*psi(ec,hc,tc)*Nuss(ec,hc,tc)*Phissadjusted(gc,ec,hc,sc,ac,tc)&
                            *cov_p(hc)*sum(pi_h(ec,tc,1:nh,hc)*e_h(1:nh,tc+1))  
                            dummy=dummy+g_dgss(gc,ec,hc,sc,ac,tc)*Nuss(ec,hc,tc)*Phissadjusted(gc,ec,hc,sc,ac,tc)
                            else
                            pr_gss1(ec,1,tc)=pr_gss1(ec,1,tc)+g_dgss(gc,ec,hc,sc,ac,tc)*psi(ec,hc,tc)*Nuss(ec,hc,tc)*Phissadjusted(gc,ec,hc,sc,ac,tc)&
                            *(1-cov_mss)*cov_p(hc)*sum(pi_h(ec,tc,1:nh,hc)*e_h(1:nh,tc+1))                                    
                            dummy=dummy+g_dgss(gc,ec,hc,sc,ac,tc)*Nuss(ec,hc,tc)*Phissadjusted(gc,ec,hc,sc,ac,tc)                                
                            end if   
                        end do
                        end do
                        end do
                        end do
                        
		buyers(ec,tc)=dummy

                        if ( dummy .gt. zero  ) then
                        
                        pr_gss1(ec,1,tc)=pr_gss1(ec,1,tc)/((1+rss)*dummy)
                        pr_gss1(ec,2:nh,tc)=pr_gss1(ec,1,tc)
                        else
                        
                        pr_gss1(ec,1,tc)=pr_gss(ec,1,tc)*0.95
                        pr_gss1(ec,2:nh,tc)=pr_gss1(ec,1,tc)
                        
				if ( rank .eq. 0 .and. tc .lt. jr ) then
	                        print*,'No one is buying private insurance Newton1ss.f90',ec,tc
				end if

                        end if
                        
                    end do
                end do
        
            d6=maxval(abs(pr_gss-pr_gss1))/10                      
        
            else 
            d6=zero
            end if
	                
            if ( rank .eq. 0 ) then
            print*,'d1 to d5 ',d1,d2,d3,d4,d5
		
                if ( conditionss .eq. 0 ) then
                print*,'d6 ',d6
                end if
                    
                open (unit=1,file='output_stst_insurance_price.txt')
                    do tc=1,J
                    write(1,'(300F12.5)')pr_gss(1,1,tc),pr_gss(2,1,tc),pr_gss1(1,1,tc),pr_gss1(2,1,tc),buyers(:,tc)
                    end do
                close(1)
                    
            end if
		
            if ( (d1 <tol) .and. (d2<tol) .and. (d3<tol) .and. (d4<tol) .and. (d5<tol) .and. (d6<tol) ) then
                exit
            end if
		
            if ( i .eq. maxit .and. rank .eq. 0 ) THEN
            print*,'iterations exceeded at Newton1ss'
                call exit
            end if

	!updating interest rate and labor
	gues1=weight*gues1+(1-weight)*ngues1
	gues2=weight*gues2+(1-weight)*ngues2
	Trss=weight*Trss+(1-weight)*Trss1
	ghexpss=weight*ghexpss+(1-weight)*ghexpss1
	taufss=weight*taufss+(1-weight)*taufss1

            if ( conditionss .eq. 0 ) then
            pr_gss=weight_p*pr_gss+(1-weight_p)*pr_gss1
            end if
                   
	end do

!prices get updated at last iteration. so call again
    call fun(gues1,gues2,fval1,fval2)

rss=gues1
Nss=gues2


end subroutine Newton1ss

