****************************************************************************8**
**   START HERE
****************************************************************************8**
** Cleaning the Data
use mepsmerged.dta, clear
format begrfy1 agey1x age1x begrfy2 age2x begrfy3 age3x begrfy4 age4x begrfy5 age5x agey2x %9.0f

* Correct the Age
	cap drop aget1
	gen aget1 = agey1x if agey1x!=-1 
	
	cap drop aget2
	gen aget2 = agey2x if agey2x!=-1
	replace aget2 = age4x if aget2==. & age4x!=-1
	
* Clean up Educ 2 Categories: HS and less, Some College and College and More
	cap drop edcat
	recode educyr (-9/-1 = .) (0/15 = 1 ) (16/17 = 2), gen (edcat)
	
	* for 2012-2013 File, Education categories are different. See code below
	replace edcat = . if inrange(eduyrdg,-9,-1)
	replace edcat = . if inlist(eduyrdg,10)
	replace edcat = 1 if inrange(eduyrdg,1,7)
	replace edcat = 2 if inrange(eduyrdg,8,9)
	
	label define edcatl 1"No College" 2"2.College&More"
	label values edcat edcatl

* Hourly Wage
* Minimum Wage from here: https://www.dol.gov/whd/minwage/chart.htm
cap drop minwage
gen minwage=.
replace minwage = 4.75 if inrange(begrfy1, 1996, 1996)
replace minwage = 5.15 if inrange(begrfy1, 1997, 2006)
replace minwage = 5.85 if inrange(begrfy1, 2007, 2007)
replace minwage = 6.55 if inrange(begrfy1, 2008, 2008)
replace minwage = 7.25 if inrange(begrfy1, 2009, 2016)

forvalues rep = 1(2)5 {
	cap drop employed`rep'
	gen employed`rep'=. 
	replace employed`rep' = 1 if inlist(empst`rep', 1, 2, 3)
	replace employed`rep' = 0 if inlist(empst`rep',4)
}
* Hours Per Week
cap drop hrwkt1 
gen hrwkt1 = hour1 
replace hrwkt1 = . if inlist(hour1, -9, -8, -7, -1)
replace hrwkt1 = hour1 if hour1>-1 & !missing(hour1)

cap drop hrwkt2 
gen hrwkt2 = . if inlist(hour3, -9, -8, -7, -1)
replace hrwkt2 = hrwkt1 if hour3==-2
replace hrwkt2 = hour3 if hour3>-1 & !missing(hour3)

replace hrwkt2 = hour5 if !inlist(hour5,-9, -8, -7, -1 , -2)
replace hrwkt2 = hour1 if hour5==-2 & hour3<0 & hour1>0 & !missing(hour1)

* Note some folks have Hours greater than 112 (16*7) and at max 168 (24*7)

* Hourly Wage
* First we use the hourly wage provided
cap drop thrwgt1
gen thrwgt1 = . if inlist(hrwg1x, -9, -8, -7, -1, -10)
replace thrwgt1 = hrwg1x if hrwg1x>-1 & !missing(hrwg1x)

cap drop thrwgt2
gen thrwgt2 = . if inlist(hrwg3x, -9, -8, -7, -1, -10)
replace thrwgt2 = hrwg1x if hrwg3x == -2 & hrwg1x>-1 & !missing(hrwg1x)
replace thrwgt2 = hrwg3x if hrwg3x>-1 & !missing(hrwg3x)

replace thrwgt2 = hrwg5x if !inlist(hrwg5x, -9, -8, -7, -1, -10,-2)
replace thrwgt2 = thrwgt1 if inlist(hrwg5x, -2) & (hrwg3x<0) & hrwg1x>0 & !missing(hrwg1x)


* * Second if hourly wage is missing, we divide the Annual wage by Work hours per week
cap drop tcombwaget1
gen tcombwaget1 = thrwgt1
replace wagepy1 = wagepy1x if wagepy1==. & wagepy1x!=. 
replace tcombwaget1 = wagepy1x/(hrwkt1 * 52) if wagepy1x>1 & hrwkt1>0 & thrwgt1==. 
replace tcombwaget1 = 76.96 if tcombwaget1>76.96 & !missing(tcombwaget1)

* Look out for variable name wagepy2x vs wagepy2
cap drop tcombwaget2
gen tcombwaget2 = thrwgt2
replace tcombwaget2 = wagepy2x/(hrwkt2 * 52) if wagepy2x>1 & hrwkt2>0 & thrwgt2==. 
replace tcombwaget2 = 76.96 if tcombwaget2>76.96 & !missing(tcombwaget2)

cap drop gdp1 
gen gdp1 = . 
replace gdp1 = 60.6 if begrfy1==1977
replace gdp1 = 113.6 if begrfy1==1987
replace gdp1 = 156.9 if begrfy1==1996
replace gdp1 = 160.5 if begrfy1==1997
replace gdp1 = 163 if begrfy1==1998
replace gdp1 = 166.6 if begrfy1==1999
replace gdp1 = 172.2 if begrfy1==2000
replace gdp1 = 177.1 if begrfy1==2001
replace gdp1 = 179.9 if begrfy1==2002
replace gdp1 = 184 if begrfy1==2003
replace gdp1 = 188.9 if begrfy1==2004
replace gdp1 = 195.3 if begrfy1==2005
replace gdp1 = 201.6 if begrfy1==2006
replace gdp1 = 207.342 if begrfy1==2007
replace gdp1 = 215.303 if begrfy1==2008
replace gdp1 = 214.537 if begrfy1==2009
replace gdp1 = 218.056 if begrfy1==2010
replace gdp1 = 224.939 if begrfy1==2011
replace gdp1 = 229.594 if begrfy1==2012
replace gdp1 = 232.957 if begrfy1==2013
replace gdp1 = 236.736 if begrfy1==2014
replace gdp1 = 237.017 if begrfy1==2015

cap drop gdp2 
gen gdp2 = . 
replace gdp2 = 60.6 if (begrfy5==1977) | (begrfy5 ==-1 & begrfy4==1977)
replace gdp2 = 113.6 if (begrfy5==1987) | (begrfy5 ==-1 & begrfy4==1987)
replace gdp2 = 156.9 if (begrfy5==1996) | (begrfy5 ==-1 & begrfy4==1996)
replace gdp2 = 160.5 if (begrfy5==1997) | (begrfy5 ==-1 & begrfy4==1997)
replace gdp2 = 163 if (begrfy5==1998) | (begrfy5 ==-1 & begrfy4==1998)
replace gdp2 = 166.6 if (begrfy5==1999) | (begrfy5 ==-1 & begrfy4==1999)
replace gdp2 = 172.2 if (begrfy5==2000) | (begrfy5 ==-1 & begrfy4==2000)
replace gdp2 = 177.1 if (begrfy5==2001) | (begrfy5 ==-1 & begrfy4==2001)
replace gdp2 = 179.9 if (begrfy5==2002) | (begrfy5 ==-1 & begrfy4==2002)
replace gdp2 = 184 if (begrfy5==2003) | (begrfy5 ==-1 & begrfy4==2003)
replace gdp2 = 188.9 if (begrfy5==2004) | (begrfy5 ==-1 & begrfy4==2004)
replace gdp2 = 195.3 if (begrfy5==2005) | (begrfy5 ==-1 & begrfy4==2005)
replace gdp2 = 201.6 if (begrfy5==2006) | (begrfy5 ==-1 & begrfy4==2006)
replace gdp2 = 207.342 if (begrfy5==2007) | (begrfy5 ==-1 & begrfy4==2007)
replace gdp2 = 215.303 if (begrfy5==2008) | (begrfy5 ==-1 & begrfy4==2008)
replace gdp2 = 214.537 if (begrfy5==2009) | (begrfy5 ==-1 & begrfy4==2009)
replace gdp2 = 218.056 if (begrfy5==2010) | (begrfy5 ==-1 & begrfy4==2010)
replace gdp2 = 224.939 if (begrfy5==2011) | (begrfy5 ==-1 & begrfy4==2011)
replace gdp2 = 229.594 if (begrfy5==2012) | (begrfy5 ==-1 & begrfy4==2012)
replace gdp2 = 232.957 if (begrfy5==2013) | (begrfy5 ==-1 & begrfy4==2013)
replace gdp2 = 236.736 if (begrfy5==2014) | (begrfy5 ==-1 & begrfy4==2014)
replace gdp2 = 237.017 if (begrfy5==2015) | (begrfy5 ==-1 & begrfy4==2015)

foreach var in hrwg combwage {
	forvalues rep = 1/2 {
		cap drop `var't`rep'
		gen `var't`rep' =.
		replace `var't`rep' = (218.056/gdp`rep') * t`var't`rep'
		*drop t`var't`rep'
		
	}
}
*******************************************************************************
forvalues x = 1/2{

replace totexpy`x'=. if totexpy`x'<0
cap drop totalexp`x'
egen totalexp`x' = rowtotal(totexpy`x'), missing /* Total Medical Expenditure including out of pocket and medicine */

replace totprvy`x'=. if totprvy`x'<0
replace totopry`x'=. if totopry`x'<0
cap drop totalprv`x'
egen totalprv`x' =  rowtotal(totprvy`x' totopry`x'), missing /* Total Private Insurance payment */

replace totslfy`x'=. if totslfy`x'<0
cap drop totalslf`x'
egen totalslf`x' =  rowtotal(totslfy`x' ), missing /* Total out of pocket and medicine */

replace totmcry`x'=. if totmcry`x'<0
replace totmcdy`x'=. if totmcdy`x'<0

cap drop totaloth`x'
gen totaloth`x' = totalexp`x' - totalslf`x' - totalprv`x'-totmcry`x'-totmcdy`x' /*Total Other*/
replace totaloth`x' = 0 if totaloth`x'<0
}

* Convert Total Expenditure in Nominal Terms to 
	* Note: Use PHCE data from : http://meps.ahrq.gov/mepsweb/about_meps/Price_Index.shtml
	* Table 3, Column 1 on Personal Health Care Overall. 

* Year 1: Convert to 2010 USD
drop if begrfy1==-1
foreach var in totalexp1 totmcry1 totmcdy1 totalslf1 totalprv1 totaloth1  {

	gen `var'_r2010 = `var' if begrfy1 ==2010
	replace `var'_r2010 = (102.7/69.1) * `var'  if begrfy1 ==1996
	replace `var'_r2010 = (102.7/70.3) * `var'  if begrfy1 ==1997
	replace `var'_r2010 = (102.7/71.8) * `var'  if begrfy1 ==1998
	replace `var'_r2010 = (102.7/73.6) * `var'  if begrfy1 ==1999
	replace `var'_r2010 = (102.7/75.7) * `var'  if begrfy1 ==2000
	replace `var'_r2010 = (102.7/78.5) * `var'  if begrfy1 ==2001
	replace `var'_r2010 = (102.7/80.9) * `var'   if begrfy1 ==2002
	replace `var'_r2010 = (102.7/83.5) * `var'  if begrfy1 ==2003
	replace `var'_r2010 = (102.7/86.5) * `var'  if begrfy1 ==2004
	replace `var'_r2010 = (102.7/89.1) * `var'   if begrfy1 ==2005
	replace `var'_r2010 = (102.7/91.8) * `var'  if begrfy1 ==2006
	replace `var'_r2010 = (102.7/94.8) * `var'  if begrfy1 ==2007
	replace `var'_r2010 = (102.7/97.3) * `var'   if begrfy1 ==2008
	replace `var'_r2010 = (102.7/100)  * `var'   if begrfy1 ==2009
	replace `var'_r2010 = (102.7/104.8) * `var'   if begrfy1 ==2011
	replace `var'_r2010 = (102.7/106.8) * `var'   if begrfy1 ==2012
	replace `var'_r2010 = (102.7/108.4) * `var'   if begrfy1 ==2013
	
} 
* Year 2: Convert to 2010 USD
foreach var in totalexp2 totmcry2 totmcdy2 totalslf2 totalprv2 totaloth2 {
	gen `var'_r2010 = `var' if begrfy5 ==2010  | (begrfy4 ==2010 & begrfy5==-1)
	replace `var'_r2010 = (102.7/69.1) * `var' if begrfy5 ==1996  | (begrfy4 ==1996 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/70.3) * `var' if begrfy5 ==1997  | (begrfy4 ==1997 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/71.8)  * `var' if begrfy5 ==1998  | (begrfy4 ==1998 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/73.6) * `var' if begrfy5 ==1999  | (begrfy4 ==1999 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/75.7) * `var' if begrfy5 ==2000  | (begrfy4 ==2000 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/78.5) * `var' if begrfy5 ==2001  | (begrfy4 ==2001 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/80.9)  * `var' if begrfy5 ==2002  | (begrfy4 ==2002 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/83.5) * `var' if begrfy5 ==2003  | (begrfy4 ==2003 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/86.5) * `var' if begrfy5 ==2004  | (begrfy4 ==2004 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/89.1) * `var' if begrfy5 ==2005  | (begrfy4 ==2005 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/91.8) * `var' if begrfy5 ==2006  | (begrfy4 ==2006 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/94.8) * `var' if begrfy5 ==2007  | (begrfy4 ==2007 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/97.3) * `var' if begrfy5 ==2008  | (begrfy4 ==2008 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/100)  * `var' if begrfy5 ==2009  | (begrfy4 ==2009 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/104.8) * `var' if begrfy5 ==2011  | (begrfy4 ==2011 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/106.8) * `var' if begrfy5 ==2012  | (begrfy4 ==2012 & begrfy5 ==-1)
	replace `var'_r2010 = (102.7/108.4) * `var' if begrfy5 ==2013  | (begrfy4 ==2013 & begrfy5 ==-1)
	}

format %12.2f *_r2010

* Save a copy
compress
save 02_meps_prep_02.dta, replace
*******************************************************************************
// SAMPLE SELECTION
** DROP VARIABLES HERE
	cap drop todrop
	gen byte todrop = 0 
	replace todrop = 1 if begrfy1>2010 
	* Drop those with inappropriate age range
	replace todrop = 1 if aget1<20 & todrop == 0 
	replace todrop = 1 if aget1>=85 & todrop == 0 
	replace todrop = 1 if edcat==. & todrop == 0 
	replace todrop = 1 if totalexp1_r2010 == . & todrop == 0 
	replace todrop = 1 if totalexp2_r2010 == . & todrop == 0	& died == 0 
compress
save 02_meps_prep_02.dta, replace
*******************************************************************************
// Assign Low, High, and Stratospheric Cost Categories Based on 60th and 99.9th percentile. 
use 02_meps_prep_02.dta, clear
gen perwt = longwt
gen newwt = perwt

gen epsilon = runiform()
replace epsilon = epsilon/10000
gen newcost1 = totalexp1_r2010 + epsilon
gen newcost2 = totalexp2_r2010 + epsilon

cap program drop prog_highcost
program define prog_highccost
svyset dupersid [pweight = newwt]
		di "lowvalue = `1'" 
		di "highvalue = `2'"
		
			if `1'>100 {
				local lowval = `1'/10
				} 
				else if `1'<100 {
				local lowval = `1'
			}
			
			if `2'>100 {
				local highval = `2'/10 
			} 	
			else if `2'<100 {
						local highval = `2'
			}
			di `lowval'
			di `highval'	
			
		quietly forvalues rep = 1/2 {
			cap drop highcost`rep'
			gen byte highcost`rep' = . 
			forvalues age = 19/86 {
				 _pctile newcost`rep' [pweight = newwt] if yearuse==1 & aget1>19 & aget1<86 & aget`rep'==`age' , p(`lowval')
				scalar plowtemp = r(r1)
				replace highcost`rep' = 1 	if newcost`rep'<plowtemp & yearuse==1 & aget1>19 & aget1<86 & aget`rep'==`age'
				replace highcost`rep' = 2   if newcost`rep'>=plowtemp & yearuse==1 & aget1>19 & aget1<86 & aget`rep'==`age'
				_pctile newcost`rep' [pweight = newwt] if yearuse==1 & aget1>19 & aget1<86 & aget`rep'==`age' , p(`highval')
				scalar phightemp = r(r1)
				replace highcost`rep' = 3 if newcost`rep'>=phightemp & !missing(newcost`rep') & aget`rep'==`age'
			}
end	

prog_highcost 60 999 // Wrote a program here because test cases involved several cutoffs. 
